@@ -45,7 +45,7 @@ Sets up the SERVER_URL environment variable
 
 sub setup_server_url {
     $ENV{SERVER_URL}
-        ||= ( "http://" . $ENV{SERVER_NAME} . ":" . $ENV{SERVER_PORT} . "/" );
+        ||= ( "http://" . ($ENV{SERVER_NAME} || 'localhost') . ":" . ( $ENV{SERVER_PORT}||80) . "/" );
 }
 
 =head2 setup_environment_from_metadata
@@ -82,6 +82,9 @@ sub setup_environment_from_metadata {
         }
     }
 
+    # Apache and lighttpd both do one layer of unescaping on
+    # path_info; we should duplicate that.
+    $ENV{PATH_INFO} = URI::Escape::uri_unescape($ENV{PATH_INFO});
 }
 
 =head2  header
